@@ -1,27 +1,23 @@
 """
     DigiCloud Image Service
 """
-from cliff.show import ShowOne
-from cliff.lister import Lister
 
-from digicloud import formatter
-from ..utils import tabulate
+from digicloud import schemas
+from digicloud.commands.base import Lister, ShowOne
 
 
 class ListImage(Lister):
     """List images"""
+    schema = schemas.ImageList(many=True)
 
-    def take_action(self, parsed_args):
+    def get_data(self, parsed_args):
         data = self.app.session.get('/images')
-
-        for image in data:
-            image['size'] = formatter.HumanBytes.format(image['size'], True)
-
-        return tabulate(data)
+        return data
 
 
 class ShowImage(ShowOne):
     """Show image details."""
+    schema = schemas.ImageDetails()
 
     def get_parser(self, prog_name):
         parser = super(ShowImage, self).get_parser(prog_name)
@@ -32,10 +28,7 @@ class ShowImage(ShowOne):
         )
         return parser
 
-    def take_action(self, parsed_args):
+    def get_data(self, parsed_args):
         uri = '/images/%s' % parsed_args.image
         data = self.app.session.get(uri)
-
-        data['size'] = formatter.HumanBytes.format(data['size'], True)
-
-        return tabulate(data)
+        return data
