@@ -106,6 +106,14 @@ class CreateInstance(ShowOne):
             default=None,
             action='store_true'
         )
+
+        parser.add_argument(
+            '--public-ip',
+            required=False,
+            metavar='<public_ip>',
+            help='Public IP name or ID to use after instance creation'
+        )
+
         parser.add_argument(
             '--additional-volumes',
             metavar='<additional_volumes>',
@@ -146,6 +154,11 @@ class CreateInstance(ShowOne):
                 "--network is mandatory in advanced mode",
             ),
 
+            (
+                parsed_args.with_public_ip and parsed_args.public_ip is not None,
+                "--with-public-ip and --public-ip must not be used together",
+            ),
+
         ]
         errors = []
         for is_invalid, err_msg in rules:
@@ -177,6 +190,8 @@ class CreateInstance(ShowOne):
             ]
         if parsed_args.with_public_ip:
             payload['has_public_ip'] = parsed_args.with_public_ip
+        if parsed_args.public_ip:
+            payload['public_ip'] = parsed_args.public_ip
         if parsed_args.description:
             payload['description'] = parsed_args.description
 
