@@ -25,7 +25,6 @@ def enrich_network_details(session, *networks):
 
 class ListNetwork(Lister):
     """List networks"""
-    help_file = 'network.txt'
     schema = schemas.NetworkList(many=True)
 
     def get_data(self, parsed_args):
@@ -90,7 +89,8 @@ class UpdateNetwork(ShowOne):
         parser.add_argument(
             '--admin-state',
             metavar='<admin_state>',
-            help='New admin state.'
+            help='New admin state.',
+            choices=("UP", "DOWN"),
         )
         return parser
 
@@ -103,7 +103,7 @@ class UpdateNetwork(ShowOne):
             payload['admin_state'] = parsed_args.admin_state
         if not payload:
             raise CLIError([dict(
-                msg="At least one of --name or --admin_state is necessary"
+                msg="At least one of --name or --admin-state is necessary"
             )])
         network = self.app.session.patch(uri, payload)
         enrich_network_details(self.app.session, network)
@@ -124,8 +124,9 @@ class CreateNetwork(ShowOne):
         parser.add_argument(
             '--admin-state',
             metavar='<AdminState>',
+            choices=("UP", "DOWN"),
             default='UP',
-            help='Set admin state (default UP).'
+            help='Set admin state, could be "UP" or "DOWN", (default UP).'
         )
         return parser
 
