@@ -6,10 +6,9 @@ import pickle
 import sys
 from pathlib import Path
 from collections import ChainMap
-from json import JSONDecodeError
 
-import yaml
-from requests import Session as Sess, HTTPError
+from requests import Session as Sess
+from sentry_sdk import capture_message
 
 
 class ConfigManager():
@@ -27,9 +26,9 @@ class ConfigManager():
 
     def __getitem__(self, item):
         try:
-            return ChainMap(self.DEFAULTS, self._states).get(item)
+            return ChainMap(self.DEFAULTS, self._states)[item]
         except KeyError:
-            raise f'No "{item}" in configuration.'
+            raise KeyError('No "{}" in configuration.'.format(item))
 
     def __setitem__(self, item, value):
         self._states[item] = value
@@ -64,7 +63,7 @@ class ConfigManager():
                 os.mkdir(path, mode=0o755)
                 self._log.debug(f'Config dir made in "{path}".')
             except IOError:
-                raise "Create config path failes."
+                raise Exception("Create config path failes.")
 
         full_path = os.path.join(path, self.FILE_NAME)
         Path(full_path).touch()
@@ -82,7 +81,7 @@ class ConfigManager():
 
     def get(self, item, default=None):
         """return item from config or default."""
-        return self.__getitem__(item) or default
+        return self._states.get(item, default)
 
     def save(self):
         """write configurations to file."""
@@ -96,51 +95,24 @@ class Session(Sess):
         self.base_url = base_url
         super(Session, self).__init__(*args, **kwargs)
 
+    @property
+    def user_agent(self):
+        return self.headers.get("User-Agent")
+
+    @user_agent.setter
+    def user_agent(self, value):
+        self.headers["User-Agent"] = value
+
     def resource(self, uri, method='GET', payload=None, params=None,
                  endpoint_version='/v1'):
         """Resource access helper."""
         url = f'{self.base_url}{endpoint_version}{uri}'
         response = self.request(method, url, params=params, json=payload)
-
-        try:
-            response.raise_for_status()
-            data = response.json()
-        except JSONDecodeError:
-            # Handel endpoints with none json payload.
-            data = {}
-        except HTTPError:
-            if response.status_code == 400:
-                if response.headers.get('Content-Type') == 'application/json':
-                    error_msg = response.json()
-                    if 'namespace_header' in error_msg:
-                        selected_ns = response.request.headers.get("Digicloud-Namespace")
-                        if selected_ns is None:
-                            raise Exception("You need to select a namespace using "
-                                            "'digicloud namespace select'")
-                        else:
-                            raise Exception(
-                                "You've chosen an invalid namespace, "
-                                "either you removed the current namespace, "
-                                "left from it or "
-                                "someone removed you.\n"
-                                "You need to select one of your namespaces using "
-                                "'digicloud namespace select'.\n"
-                                "Also you can see list of your namespaces using "
-                                "'digicloud namespace list'"
-                            )
-                    if 'region_header' in error_msg:
-                        raise Exception("You need to select a region appropriately, "
-                                        "by using 'digicloud region select' and "
-                                        "'digicloud region list'")
-            if response.status_code == 401 and not response.url.endswith('tokens'):
-                error_msg = 'digicloud: Must login.'
-            elif response.headers.get('Content-Type') == 'application/json':
-                error_msg = yaml.safe_dump(response.json())
-            else:
-                error_msg = f'digicloud: {response.reason}({response.status_code})'
-            raise Exception(error_msg)
-
-        return data
+        self.log_to_sentry(response)
+        response.raise_for_status()
+        if len(response.content):
+            return response.json()
+        return None
 
     def get(self, uri, params=None):
         return self.resource(uri, params=params)
@@ -156,3 +128,18 @@ class Session(Sess):
 
     def delete(self, uri, payload=None):
         return self.resource(uri, 'DELETE', payload)
+
+    def setup(self, config):
+        self.base_url = config['BASE_URL']
+        if config.get('AUTH_HEADERS'):
+            auth_headers = config['AUTH_HEADERS']
+            self.headers.update(auth_headers)
+        else:
+            config['AUTH_HEADERS'] = dict()
+
+    def log_to_sentry(self, response):
+        response_time = round(response.elapsed.total_seconds(), 1)
+        if response_time > 10:
+            capture_message('slow-response: url: {} time: {} seconds'.format(
+                response.request.url, response_time
+            ))
